require 'omniauth-oauth2'

module OmniAuth
  module Strategies

    #
    # Authenticate with the TxSSC SSO
    #

    class TxSSC < OmniAuth::Strategies::OAuth2

      option :name, 'txssc'
      option :provider_ignores_state, true

      option :client_options, {
        :site => 'https://sso.txssc.txstate.edu',
        :authorize_url => 'https://sso.txssc.txstate.edu/oauth2/authorize',
        :token_url => 'https://sso.txssc.txstate.edu/oauth2/access_token'
      }

      uid { raw_info['id'] }

      info do
        {
          'name' => raw_info['name'],
          'username' => raw_info['username'],
          'email' => raw_info['email'],
          'role' => raw_info['role'],
          'avatar' => raw_info['avatar']
        }
      end

      def raw_info
        access_token.options[:mode] = :query
        access_token.options[:param_name] = :access_token
        @raw_info ||= access_token.get('/me').parsed
      end
      
      def callback_url
        full_host + script_name + callback_path
      end
    end
  end
end

OmniAuth.config.add_camelization('txssc', 'TxSSC')
